<!DOCTYPE html>
<html>
<head lang="en">
    <meta charset="UTF-8">
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.1/css/bootstrap.min.css">
    <title>Server Error</title>
</head>
<body>
    <div class="container">
        <div class="col-sm-6 col-sm-offset-3">
            <br>
            <br>
            <br>
            <div class="panel panel-default">
                <div class="panel-heading">Unknown Error</div>
                <div class="panel-body">
                    이용에 불편을 드려 죄송합니다.
                    <br>
                    <br>
                    <a class="btn btn-primary" href="/">첫 페이지로</a>
                    <a class="btn btn-default" href="javascript:history.back()">뒤로 돌아가기</a>
                </div>
            </div>
        </div>
    </div>
</body>
</html>